aboutsummaryrefslogtreecommitdiffstats
path: root/cps-service/src/main/java/org/onap/cps/api/CpsModuleService.java
diff options
context:
space:
mode:
Diffstat (limited to 'cps-service/src/main/java/org/onap/cps/api/CpsModuleService.java')
-rw-r--r--cps-service/src/main/java/org/onap/cps/api/CpsModuleService.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/cps-service/src/main/java/org/onap/cps/api/CpsModuleService.java b/cps-service/src/main/java/org/onap/cps/api/CpsModuleService.java
index 02553d0741..94ebea2fc2 100644
--- a/cps-service/src/main/java/org/onap/cps/api/CpsModuleService.java
+++ b/cps-service/src/main/java/org/onap/cps/api/CpsModuleService.java
@@ -20,7 +20,7 @@
package org.onap.cps.api;
import java.io.File;
-import org.onap.cps.exceptions.CpsValidationException;
+import org.onap.cps.spi.exceptions.CpsException;
import org.opendaylight.yangtools.yang.model.api.SchemaContext;
/**
@@ -49,7 +49,7 @@ public interface CpsModuleService {
*
* @param schemaContext the schema context
* @param dataspaceName the dataspace name
* @throws CpsValidationException if input data already exists.
*/
void storeSchemaContext(SchemaContext schemaContext, String dataspaceName);
}
@@ -49,7 +49,7 @@ public interface CpsModuleService {
* @param schemaContext the schema context
* @param dataspaceName the dataspace name
- * @throws CpsValidationException if input data already exists.
+ * @throws CpsException if input data already exists.
*/
void storeSchemaContext(SchemaContext schemaContext, String dataspaceName);